==> fiftyone_devicedetection_onpremise-4.2.6.tar.gz: fiftyone_devicedetection_onpremise-4.2.6/fiftyone_devicedetection_onpremise/device-detection-cxx/src/common-cxx/Date.cpp <==
/* *********************************************************************
 * This Original Work is copyright of 51 Degrees Mobile Experts Limited.
 * Copyright 2019 51 Degrees Mobile Experts Limited, 5 Charlotte Close,
 * Caversham, Reading, Berkshire, United Kingdom RG4 7BY.
 *
 * This Original Work is licensed under the European Union Public Licence (EUPL) 
 * v.1.2 and is subject to its terms as set out below.
 *
 * If a copy of the EUPL was not distributed with this file, You can obtain
 * one at https://opensource.org/licenses/EUPL-1.2.
 *
 * The 'Compatible Licences' set out in the Appendix to the EUPL (as may be
 * amended by the European Commission) shall be deemed incompatible for
 * the purposes of the Work and the provisions of the compatibility
 * clause in Article 5 of the EUPL shall not apply.
 * 
 * If using the Work as, or as part of, a network application, by 
 * including the attribution notice(s) required under Article 5 of the EUPL
 * in the end user terms of the application under an appropriate heading, 
 * such notice(s) shall fulfill the requirements of that article.
 * ********************************************************************* */

#include "Date.hpp"

#include "fiftyone.h"

using namespace FiftyoneDegrees::Common;

Date::Date() {
	date.year = 0;
	date.month = 0;
	date.day = 0;
}

Date::Date(const fiftyoneDegreesDate *date) {
	this->date = *date;
}

int Date::getYear() { return date.year; }

int Date::getMonth() { return date.month; }

int Date::getDay() { return date.day; }

==> fiftyone_devicedetection_onpremise-4.4.2.tar.gz: fiftyone_devicedetection_onpremise-4.4.2/fiftyone_devicedetection_onpremise/device-detection-cxx/src/common-cxx/Date.cpp <==
/* *********************************************************************
 * This Original Work is copyright of 51 Degrees Mobile Experts Limited.
 * Copyright 2019 51 Degrees Mobile Experts Limited, 5 Charlotte Close,
 * Caversham, Reading, Berkshire, United Kingdom RG4 7BY.
 *
 * This Original Work is licensed under the European Union Public Licence (EUPL) 
 * v.1.2 and is subject to its terms as set out below.
 *
 * If a copy of the EUPL was not distributed with this file, You can obtain
 * one at https://opensource.org/licenses/EUPL-1.2.
 *
 * The 'Compatible Licences' set out in the Appendix to the EUPL (as may be
 * amended by the European Commission) shall be deemed incompatible for
 * the purposes of the Work and the provisions of the compatibility
 * clause in Article 5 of the EUPL shall not apply.
 * 
 * If using the Work as, or as part of, a network application, by 
 * including the attribution notice(s) required under Article 5 of the EUPL
 * in the end user terms of the application under an appropriate heading, 
 * such notice(s) shall fulfill the requirements of that article.
 * ********************************************************************* */

#include "Date.hpp"

#include "fiftyone.h"

using namespace FiftyoneDegrees::Common;

Date::Date() {
	date.year = 0;
	date.month = 0;
	date.day = 0;
}

Date::Date(const fiftyoneDegreesDate *date) {
	this->date = *date;
}

int Date::getYear() const { return date.year; }

int Date::getMonth() const { return date.month; }

int Date::getDay() const { return date.day; }
